@@ -3,18 +3,16 @@
 t_to_d <- function(t, df_error,
                    paired = FALSE,
                    ci = 0.95, alternative = "two.sided", ...) {
-  alternative <- match.arg(alternative, c("two.sided", "less", "greater"))
+  alternative <- .match.alt(alternative)
 
   # Will be 1 if TRUE, and 2 if FALSE
   paired <- 2 - paired
 
   res <- data.frame(d = paired * t / sqrt(df_error))
 
-  ci_method <- NULL
-  if (is.numeric(ci)) {
-    stopifnot(length(ci) == 1, ci < 1, ci > 0)
+  if (.test_ci(ci)) {
     res$CI <- ci
-    ci.level <- if (alternative == "two.sided") ci else 2 * ci - 1
+    ci.level <- .adjust_ci(ci, alternative)
 
     ts <- t(mapply(
       .get_ncp_t,
@@ -25,13 +23,9 @@ t_to_d <- function(t, df_error,
     res$CI_high <- paired * ts[, 2] / sqrt(df_error)
 
     ci_method <- list(method = "ncp", distribution = "t")
-    if (alternative == "less") {
-      res$CI_low <- -Inf
-    } else if (alternative == "greater") {
-      res$CI_high <- Inf
-    }
+    res <- .limit_ci(res, alternative, -Inf, Inf)
   } else {
-    alternative <- NULL
+    ci_method <- alternative <- NULL
   }
 
   class(res) <- c("effectsize_table", "see_effectsize_table", class(res))
@@ -55,18 +49,16 @@ z_to_d <- function(z, n,
                    paired = FALSE,
                    ci = 0.95, alternative = "two.sided",
                    ...) {
-  alternative <- match.arg(alternative, c("two.sided", "less", "greater"))
+  alternative <- .match.alt(alternative)
 
   # Will be 1 if TRUE, and 2 if FALSE
   paired <- 2 - paired
 
   res <- data.frame(d = paired * z / sqrt(n))
 
-  ci_method <- NULL
-  if (is.numeric(ci)) {
-    stopifnot(length(ci) == 1, ci < 1, ci > 0)
+  if (.test_ci(ci)) {
     res$CI <- ci
-    ci.level <- if (alternative == "two.sided") ci else 2 * ci - 1
+    ci.level <- .adjust_ci(ci, alternative)
 
     alpha <- 1 - ci.level
     probs <- c(alpha / 2, 1 - alpha / 2)
@@ -78,13 +70,9 @@ z_to_d <- function(z, n,
     res$CI_high <- paired * zs[, 2] / sqrt(n)
 
     ci_method <- list(method = "normal")
-    if (alternative == "less") {
-      res$CI_low <- -Inf
-    } else if (alternative == "greater") {
-      res$CI_high <- Inf
-    }
+    res <- .limit_ci(res, alternative, -Inf, Inf)
   } else {
-    alternative <- NULL
+    ci_method <- alternative <- NULL
   }
 
   class(res) <- c("effectsize_table", "see_effectsize_table", class(res))
